@@ -2,6 +2,7 @@
 This file contains a hack to make swagger-ui work from behind a load balancer.
 It contains no application specific code and could have been a library.
 """
+import flask
 from flask_restplus import Api
 from flask_restplus.api import SwaggerView
 
@@ -24,3 +25,8 @@ class CustomAPI(Api):
                 endpoint=endpoint,
                 resource_class_args=(self, ))
             self.endpoints.add(endpoint)
+
+    @property
+    def specs_url(self):
+        """Swagger URI protocol-relative."""
+        return flask.url_for(self.endpoint('specs'), _external=True, _scheme="")
