@@ -2,17 +2,18 @@ import logging
 import os
 
 from flask import Blueprint, Flask, url_for
-from flask_restplus import Resource, apidoc
+from flask_restplus import Resource, apidoc, Namespace
+from werkzeug.middleware.proxy_fix import ProxyFix
 
+from apian.api import CustomAPI
+from apian.auth import AUTH_CONFIG_KEY, authentication_enabled
 from apian.config import init_logging
 from apian.meta import read_version
-from apian.api import CustomAPI
-from apian.auth import authentication_enabled, AUTH_CONFIG_KEY
 
 log = logging.getLogger(__name__)
 
 
-def create_api(name, config):
+def create_api(name, config, *, title=None, **extra):
     # pylint: disable=unused-variable
     """Create an API with info and health endpoints.
 
@@ -23,9 +24,8 @@ def create_api(name, config):
     :returns: An instance of :class:`~apian.api.CustomAPI`.
     """
     prefix = "/{}/api".format(name)
-    title = _title_from_name(name)
+    title = _title_from_name(name) if title is None else title
     blueprint = Blueprint(prefix, __name__)
-    extra = {}
     if authentication_enabled(config.get(AUTH_CONFIG_KEY)):
         extra["security"] = "Bearer Auth"
 
@@ -34,21 +34,23 @@ def create_api(name, config):
         }
 
     api = CustomAPI(blueprint, title=title, prefix=prefix, doc=prefix + "/", **extra)
+    ns = Namespace(name="Generic", path="/")
 
-    @api.route("/info")
+    @ns.route("/info")
     class Info(Resource):
         def get(self):
             # pylint: disable=no-self-use
             """Show information about the service"""
             return {"name": name, "version": read_version(), "config": config["__path"]}
 
-    @api.route("/health")
+    @ns.route("/health")
     class Health(Resource):
         def get(self):
             # pylint: disable=no-self-use
             """Check the health of the service"""
             return {"status": "ok"}
 
+    api.add_namespace(ns)
     return api
 
 
@@ -72,6 +74,7 @@ def create_app(api, config):
     swagger = _create_swagger()
     app.register_blueprint(api.blueprint)
     app.register_blueprint(swagger, url_prefix=api.prefix)
+    app.wsgi_app = ProxyFix(app.wsgi_app)
 
     return app
 
